{% load i18n %}
<!DOCTYPE html>
<html lang="en">
<head>
  <meta charset="UTF-8">
  <title>{% trans "Timeline logger notification" %}</title>
</head>
<body>
  <h3>{% blocktrans trimmed with start_date=start_date|date:'DATE_FORMAT' %}
      Events since {{ start_date }}
  {% endblocktrans %}</h3>

  {% if logs %}
    <ul>
      {% for log in logs %}
        <li>{{ log.get_message }}</li>
      {% endfor %}
    </ul>
  {% else %}
    <p>{% trans "No events logged from that date until today." %}</p>
  {% endif %}
</body>
</html>
