# -*- coding: utf-8 -*-
# Generated by Django 1.11.9 on 2018-03-13 17:38
from __future__ import unicode_literals

from django.conf import settings
import django.contrib.postgres.fields.jsonb
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('timeline_logger', '0003_auto_20171025_1414'),
    ]

    operations = [
        migrations.AlterField(
            model_name='timelinelog',
            name='content_type',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='contenttypes.ContentType', verbose_name='content type'),
        ),
        migrations.AlterField(
            model_name='timelinelog',
            name='extra_data',
            field=django.contrib.postgres.fields.jsonb.JSONField(blank=True, null=True, verbose_name='extra data'),
        ),
        migrations.AlterField(
            model_name='timelinelog',
            name='object_id',
            field=models.TextField(blank=True, null=True, verbose_name='object id'),
        ),
        migrations.AlterField(
            model_name='timelinelog',
            name='timestamp',
            field=models.DateTimeField(auto_now_add=True, verbose_name='timestamp'),
        ),
        migrations.AlterField(
            model_name='timelinelog',
            name='user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL, verbose_name='user'),
        ),
    ]
